@@ -178,7 +178,7 @@ static void show_statfs(const char *path)
     }
 }
 #else
-# define show_statfs(p)
+#  define show_statfs(p)
 #endif
 
 /****************************************************************************
@@ -212,7 +212,8 @@ static void show_directories(const char *path, int indent)
         {
           char *subdir;
           printf("%s/\n", direntry->d_name);
-          sprintf(g_namebuffer, "%s/%s", path, direntry->d_name);
+          snprintf(g_namebuffer, sizeof(g_namebuffer),
+                   "%s/%s", path, direntry->d_name);
           subdir = strdup(g_namebuffer);
           show_directories(subdir, indent + 1);
           free(subdir);
@@ -226,7 +227,7 @@ static void show_directories(const char *path, int indent)
   closedir(dirp);
 }
 #else
-# define show_directories(p,i)
+#  define show_directories(p,i)
 #endif
 
 /****************************************************************************
@@ -557,7 +558,7 @@ static void fail_stat(const char *path, int expectederror)
     }
 }
 #else
-# define fail_stat(p,e);
+#  define fail_stat(p,e);
 #endif
 
 /****************************************************************************
