@@ -77,19 +77,19 @@ TEST_TEAR_DOWN(no_block_connect)
   if (sd >= 0)
     {
       ret = close(sd);
-      assert(ret == 0);
+      TEST_ASSERT_EQUAL(ret, 0);
     }
 
   if (sd2 >= 0)
     {
       ret = close(sd2);
-      assert(ret == 0);
+      TEST_ASSERT_EQUAL(ret, 0);
     }
 
   if (started)
     {
       ret = usrsocktest_daemon_stop();
-      assert(ret == OK);
+      TEST_ASSERT_EQUAL(ret, OK);
     }
 }
 
