@@ -123,6 +123,60 @@ struct netlib_device_s
 };
 #endif /* CONFIG_NETLINK_ROUTE*/
 
+#ifdef CONFIG_NETLINK_NETFILTER
+/* Describes one connection returned by netlib_get_conntrack() */
+
+union netlib_conntrack_addr_u
+{
+#ifdef CONFIG_NET_IPv4
+  struct in_addr ipv4;
+#endif
+#ifdef CONFIG_NET_IPv6
+  struct in6_addr ipv6;
+#endif
+};
+
+struct netlib_conntrack_tuple_s
+{
+  union netlib_conntrack_addr_u src;
+  union netlib_conntrack_addr_u dst;
+
+  union
+  {
+    struct
+    {
+      uint16_t sport;
+      uint16_t dport;
+    } tcp; /* and udp */
+
+    struct
+    {
+      uint16_t id;
+      uint8_t  type;
+      uint8_t  code;
+    } icmp; /* and icmp6 */
+  } l4;
+
+  uint8_t l4proto;
+};
+
+struct netlib_conntrack_s
+{
+  struct netlib_conntrack_tuple_s orig;
+  struct netlib_conntrack_tuple_s reply;
+
+  sa_family_t family; /* AF_INET or AF_INET6 */
+  uint8_t     type;   /* IPCTNL_MSG_CT_* */
+};
+
+/* There might be many conntrack entries, so we don't use array of data, but
+ * use callback instead.
+ */
+
+typedef CODE int (*netlib_conntrack_cb_t)(FAR struct netlib_conntrack_s *ct);
+
+#endif /* CONFIG_NETLINK_NETFILTER */
+
 #ifdef CONFIG_NETUTILS_NETLIB_GENERICURLPARSER
 struct url_s
 {
@@ -336,11 +390,16 @@ int netlib_obtain_ipv6addr(FAR const char *ifname);
 
 struct ipt_replace;  /* Forward reference */
 struct ipt_entry;    /* Forward reference */
+struct ip6t_replace; /* Forward reference */
+struct ip6t_entry;   /* Forward reference */
 enum nf_inet_hooks;  /* Forward reference */
 
+#  ifdef CONFIG_NET_IPv4
 FAR struct ipt_replace *netlib_ipt_prepare(FAR const char *table);
 int netlib_ipt_commit(FAR const struct ipt_replace *repl);
 int netlib_ipt_flush(FAR const char *table, enum nf_inet_hooks hook);
+int netlib_ipt_policy(FAR const char *table, enum nf_inet_hooks hook,
+                      int verdict);
 int netlib_ipt_append(FAR struct ipt_replace **repl,
                       FAR const struct ipt_entry *entry,
                       enum nf_inet_hooks hook);
@@ -350,9 +409,52 @@ int netlib_ipt_insert(FAR struct ipt_replace **repl,
 int netlib_ipt_delete(FAR struct ipt_replace *repl,
                       FAR const struct ipt_entry *entry,
                       enum nf_inet_hooks hook, int rulenum);
-#  ifdef CONFIG_NET_NAT
+int netlib_ipt_fillifname(FAR struct ipt_entry *entry,
+                          FAR const char *inifname,
+                          FAR const char *outifname);
+#    ifdef CONFIG_NET_NAT
 FAR struct ipt_entry *netlib_ipt_masquerade_entry(FAR const char *ifname);
-#  endif
+#    endif
+#    ifdef CONFIG_NET_IPFILTER
+FAR struct ipt_entry *netlib_ipt_filter_entry(FAR const char *target,
+                                              int verdict,
+                                              uint8_t match_proto);
+#    endif
+#  endif /* CONFIG_NET_IPv4 */
+#  ifdef CONFIG_NET_IPv6
+FAR struct ip6t_replace *netlib_ip6t_prepare(FAR const char *table);
+int netlib_ip6t_commit(FAR const struct ip6t_replace *repl);
+int netlib_ip6t_flush(FAR const char *table, enum nf_inet_hooks hook);
+int netlib_ip6t_policy(FAR const char *table, enum nf_inet_hooks hook,
+                       int verdict);
+int netlib_ip6t_append(FAR struct ip6t_replace **repl,
+                       FAR const struct ip6t_entry *entry,
+                       enum nf_inet_hooks hook);
+int netlib_ip6t_insert(FAR struct ip6t_replace **repl,
+                       FAR const struct ip6t_entry *entry,
+                       enum nf_inet_hooks hook, int rulenum);
+int netlib_ip6t_delete(FAR struct ip6t_replace *repl,
+                       FAR const struct ip6t_entry *entry,
+                       enum nf_inet_hooks hook, int rulenum);
+int netlib_ip6t_fillifname(FAR struct ip6t_entry *entry,
+                           FAR const char *inifname,
+                           FAR const char *outifname);
+#    ifdef CONFIG_NET_IPFILTER
+FAR struct ip6t_entry *netlib_ip6t_filter_entry(FAR const char *target,
+                                                int verdict,
+                                                uint8_t match_proto);
+#    endif
+#  endif /* CONFIG_NET_IPv6 */
+#endif /* CONFIG_NET_IPTABLES */
+
+#ifdef CONFIG_NETLINK_NETFILTER
+/* Netfilter connection tracking support */
+
+struct nlmsghdr;  /* Forward reference */
+
+int netlib_parse_conntrack(FAR const struct nlmsghdr *nlh, size_t len,
+                           FAR struct netlib_conntrack_s *ct);
+int netlib_get_conntrack(sa_family_t family, netlib_conntrack_cb_t cb);
 #endif
 
 /* HTTP support */
