@@ -28,6 +28,7 @@
 
 const char *const toywasm_config_string =
 "\tTOYWASM_USE_SEPARATE_EXECUTE = ON\n"
+"\tTOYWASM_USE_SEPARATE_VALIDATE = OFF\n"
 "\tTOYWASM_USE_TAILCALL = ON\n"
 "\tTOYWASM_FORCE_USE_TAILCALL = OFF\n"
 "\tTOYWASM_USE_SIMD = OFF\n"
@@ -54,8 +55,11 @@ const char *const toywasm_config_string =
 "\tTOYWASM_ENABLE_WASM_MULTI_MEMORY = ON\n"
 "\tTOYWASM_ENABLE_WASM_TAILCALL = ON\n"
 "\tTOYWASM_ENABLE_WASM_THREADS = ON\n"
+"\tTOYWASM_ENABLE_WASM_CUSTOM_PAGE_SIZES = ON\n"
 "\tTOYWASM_ENABLE_WASM_NAME_SECTION = ON\n"
 "\tTOYWASM_ENABLE_WASI = ON\n"
 "\tTOYWASM_ENABLE_WASI_THREADS = ON\n"
+"\tTOYWASM_ENABLE_WASI_LITTLEFS = OFF\n"
+"\tTOYWASM_ENABLE_LITTLEFS_STATS = OFF\n"
 "\tTOYWASM_ENABLE_DYLD = ON\n"
 "\tTOYWASM_ENABLE_DYLD_DLFCN = ON\n";
