@@ -245,7 +245,7 @@ static int send_internal_at_command(FAR struct alt1250_s *dev,
 
   err_alt1250("Internal ATCMD : %s\n", dev->tx_buff);
 
-  ret = altdevice_send_command(dev->altfd, container, usock_result);
+  ret = altdevice_send_command(dev, dev->altfd, container, usock_result);
   if (ret == REP_NO_ACK)
     {
       /* In case of no error */
@@ -431,6 +431,33 @@ int ltenwop_send_setnwoptp(FAR struct alt1250_s *dev,
   return send_internal_at_command(dev, container, -1, NULL, 0, &dummy);
 }
 
+/****************************************************************************
+ * name: ltesp_send_getscanplan
+ ****************************************************************************/
+
+int ltesp_send_getscanplan(FAR struct alt1250_s *dev,
+                           FAR struct alt_container_s *container)
+{
+  int32_t dummy;
+  snprintf((FAR char *)dev->tx_buff, _TX_BUFF_SIZE,
+           "AT%%GETCFG=\"SCAN_PLAN_EN\"\r");
+  return send_internal_at_command(dev, container, -1, NULL, 0, &dummy);
+}
+
+/****************************************************************************
+ * name: ltesp_send_setscanplan
+ ****************************************************************************/
+
+int ltesp_send_setscanplan(FAR struct alt1250_s *dev,
+                           FAR struct alt_container_s *container,
+                           bool enable)
+{
+  int32_t dummy;
+  snprintf((FAR char *)dev->tx_buff, _TX_BUFF_SIZE,
+           "AT%%SETCFG=\"SCAN_PLAN_EN\",\"%s\"\r", (enable ? "1" : "0"));
+  return send_internal_at_command(dev, container, -1, NULL, 0, &dummy);
+}
+
 /****************************************************************************
  * name: lwm2mstub_send_getqueuemode
  ****************************************************************************/
