@@ -109,6 +109,13 @@ int ltenwop_send_getnwop(FAR struct alt1250_s *dev,
 int ltenwop_send_setnwoptp(FAR struct alt1250_s *dev,
                            FAR struct alt_container_s *container);
 
+int ltesp_send_getscanplan(FAR struct alt1250_s *dev,
+                           FAR struct alt_container_s *container);
+
+int ltesp_send_setscanplan(FAR struct alt1250_s *dev,
+                           FAR struct alt_container_s *container,
+                           bool enable);
+
 int lwm2mstub_send_getqueuemode(FAR struct alt1250_s *dev,
                                 FAR struct alt_container_s *container,
                                 int16_t usockid, FAR int32_t *ures);
