@@ -41,7 +41,8 @@
  * Private Function Prototypes
  ****************************************************************************/
 
-static int i2ccmd_help(FAR struct i2ctool_s *i2ctool, int argc, char **argv);
+static int i2ccmd_help(FAR struct i2ctool_s *i2ctool,
+                       int argc, FAR char **argv);
 static int i2ccmd_unrecognized(FAR struct i2ctool_s *i2ctool, int argc,
                                FAR char **argv);
 
@@ -96,7 +97,8 @@ const char g_i2cxfrerror[]    = "i2ctool: %s: Transfer failed: %d\n";
  * Name: i2ccmd_help
  ****************************************************************************/
 
-static int i2ccmd_help(FAR struct i2ctool_s *i2ctool, int argc, char **argv)
+static int i2ccmd_help(FAR struct i2ctool_s *i2ctool, int argc,
+                       FAR char **argv)
 {
   const struct cmdmap_s *ptr;
 
@@ -221,7 +223,7 @@ static int i2c_execute(FAR struct i2ctool_s *i2ctool, int argc,
  ****************************************************************************/
 
 static FAR char *i2c_argument(FAR struct i2ctool_s *i2ctool,
-                              int argc, char *argv[], int *pindex)
+                              int argc, FAR char *argv[], FAR int *pindex)
 {
   FAR char *arg;
   int  index = *pindex;
@@ -266,7 +268,8 @@ static FAR char *i2c_argument(FAR struct i2ctool_s *i2ctool,
  * Name: i2c_parse
  ****************************************************************************/
 
-static int i2c_parse(FAR struct i2ctool_s *i2ctool, int argc, char *argv[])
+static int i2c_parse(FAR struct i2ctool_s *i2ctool,
+                     int argc, FAR char *argv[])
 {
   FAR char *newargs[MAX_ARGUMENTS + 2];
   FAR char *cmd;
