@@ -38,6 +38,7 @@
 #include <strings.h>
 #include <sys/ioctl.h>
 #include <sys/types.h>
+#include <sys/param.h>
 #include <unistd.h>
 #ifdef CONFIG_NXPLAYER_HTTP_STREAMING_SUPPORT
 #  include <sys/time.h>
@@ -92,6 +93,9 @@ int nxplayer_getmidisubformat(int fd);
 int nxplayer_getmp3subformat(int fd);
 #endif
 
+#ifdef CONFIG_AUDIO_FORMAT_SBC
+int nxplayer_getsbcsubformat(int fd);
+#endif
 /****************************************************************************
  * Private Data
  ****************************************************************************/
@@ -119,7 +123,10 @@ static const struct nxplayer_ext_fmt_s g_known_ext[] =
   { "midi",     AUDIO_FMT_MIDI, nxplayer_getmidisubformat },
 #endif
 #ifdef CONFIG_AUDIO_FORMAT_OGG_VORBIS
-  { "ogg",      AUDIO_FMT_OGG_VORBIS, NULL }
+  { "ogg",      AUDIO_FMT_OGG_VORBIS, NULL },
+#endif
+#ifdef CONFIG_AUDIO_FORMAT_SBC
+  { "sbc",      AUDIO_FMT_SBC, nxplayer_getsbcsubformat }
 #endif
 };
 
@@ -133,6 +140,11 @@ static const struct nxplayer_dec_ops_s g_dec_ops[] =
     nxplayer_parse_mp3,
     nxplayer_fill_common
   },
+  {
+    AUDIO_FMT_SBC,
+    nxplayer_parse_sbc,
+    nxplayer_fill_common
+  },
   {
     AUDIO_FMT_PCM,
     NULL,
@@ -534,6 +546,13 @@ int nxplayer_getmp3subformat(int fd)
 }
 #endif
 
+#ifdef CONFIG_AUDIO_FORMAT_SBC
+int nxplayer_getsbcsubformat(int fd)
+{
+  return AUDIO_FMT_SBC;
+}
+#endif
+
 /****************************************************************************
  * Name: nxplayer_fmtfromextension
  *
@@ -1882,7 +1901,7 @@ static int nxplayer_playinternal(FAR struct nxplayer_s *pplayer,
       goto err_out_nodev;
     }
 
-  for (c = 0; c < sizeof(g_dec_ops) / sizeof(g_dec_ops[0]); c++)
+  for (c = 0; c < nitems(g_dec_ops); c++)
     {
       if (g_dec_ops[c].format == filefmt)
         {
