@@ -154,6 +154,13 @@ int spicmd_exch(FAR struct spitool_s *spitool, int argc, FAR char **argv)
   seq.ntrans = 1;
   seq.trans = &trans;
 
+#ifdef CONFIG_SPI_DELAY_CONTROL
+  seq.a = 0;
+  seq.b = 0;
+  seq.i = 0;
+  seq.c = 0;
+#endif
+
   trans.deselect = true;
 #ifdef CONFIG_SPI_CMDDATA
   trans.cmd = spitool->command;
